<?php
/**
 * Russian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Denis Simakov <akinoame1@gmail.com>
 */
 
$lang['menu'] = 'Управление пользователями'; 
 
// custom language strings for the plugin
$lang['noauth']      = '(авторизация пользователей недоступна)';
$lang['nosupport']   = '(управление пользователями не поддерживается)';

$lang['badauth']     = 'некорректный механизм аутентификации';     // should never be displayed!

$lang['user_id']     = 'Логин';
$lang['user_pass']   = 'Пароль';
$lang['user_name']   = 'Полное имя';
$lang['user_mail']   = 'Е-мэйл';
$lang['user_groups'] = 'Группы';

$lang['field']       = 'Поле';
$lang['value']       = 'Значение';
$lang['add']         = 'Добавить';
$lang['delete']      = 'Удалить';
$lang['delete_selected'] = 'Удалить выбранные';
$lang['edit']        = 'Редактировать';
$lang['edit_prompt'] = 'Редактировать этого пользователя';
$lang['modify']      = 'Сохранить изменения';
$lang['search']      = 'Поиск';
$lang['search_prompt'] = 'Искать';
$lang['clear']       = 'Сброс фильтра поиска';
$lang['filter']      = 'Фильтр';

$lang['summary']     = 'Показаны пользователи %1$d-%2$d из %3$d найденных. Всего пользователей: %4$d.';
$lang['nonefound']   = 'Не найдено ни одного пользователя. Всего пользователей: %d.';
$lang['delete_ok']   = 'Удалено пользователей: %d';
$lang['delete_fail'] = 'Не удалось удалить %d.';
$lang['update_ok']   = 'Пользователь успешно обновлен';
$lang['update_fail'] = 'Не удалось обновить пользователя';
$lang['update_exists'] = 'Не удалось изменить имя пользователя, такой пользователь (%s) уже существует (все остальные изменения будут применены).';

$lang['start']  = 'в начало';
$lang['prev']   = 'назад';
$lang['next']   = 'вперед';
$lang['last']   = 'в конец';

// added after 2006-03-09 release
$lang['edit_usermissing'] = 'Выбранный пользователь не найден. Возможно, указанный логин был удален или изменен извне.';
$lang['user_notify'] = 'Сообщить пользователю';
$lang['note_notify'] = 'Е-мэйлы с уведомлением посылаются только в случае получения нового пароля.';
$lang['note_group'] = 'Если группа не указана, новые пользователи будут добавлены в группу по умолчанию (%s).';
$lang['add_ok'] = 'Пользователь успешно добавлен';
$lang['add_fail'] = 'Не удалось добавить пользователя';
$lang['notify_ok'] = 'Е-мэйл с уведомлением был послан';
$lang['notify_fail'] = 'Не удалось послать е-мэйл с уведомлением';

